@@ -10,19 +10,20 @@
 
 
 """
-                                  Screenpy
+                                  ScreenPy
                                                                       FADE IN:
 INT. SITEPACKAGES DIRECTORY
 
-Screenpy is a composition-based test framework. It is inspired by the
+ScreenPy is a composition-based test framework. It is inspired by the
 SerenityBDD library for Java.
 
-:copyright: (c) 2019–2020 by Perry Goy.
+:copyright: (c) 2019–2021 by Perry Goy.
 :license: MIT, see LICENSE for more details.
 """
 
 
 from .actor import Actor
+from .director import Director
 from .given_when_then import and_, given, given_that, then, when
 from .target import Target
 
@@ -33,6 +34,7 @@ AnActor = Actor
 __all__ = [
     "Actor",
     "AnActor",
+    "Director",
     "Target",
     "and_",
     "given",
