@@ -1,26 +1,21 @@
 """
-A meta-action to perform lower level actions. An actor will probably need the
-ability to BrowseTheWeb to perform this action. An actor performs this action
-like so:
+A meta-Action to group a series of chainable Actions together.
+"""
 
-    the_actor.attempts_to(
-        Chain(Hover.on_the(MENU_ELEMENT), Click.on_the(SUBMENU_ELEMENT))
-    )
-"""
+from selenium.webdriver.common.action_chains import ActionChains
 
 from screenpy.abilities import BrowseTheWeb
 from screenpy.actor import Actor
 from screenpy.exceptions import UnableToAct
 from screenpy.pacing import beat
 from screenpy.protocols import Chainable
-from selenium.webdriver.common.action_chains import ActionChains
 
 
 class Chain:
-    """
-    A meta-action to group a series of lower-level actions together, like
-    hovering and dragging. A Chain action is expected to be instantiated with
-    a list of actions to perform in a series.
+    """A meta-Action to group a series of chainable Actions together
+
+    A Chain Action is expected to be instantiated with a list of Actions to
+    perform in a series.
 
     Abilities Required:
         |BrowseTheWeb|
@@ -31,19 +26,19 @@ class Chain:
             Chain(Hover.on_the(MENU_ICON), Click.on_the(SUBMENU_LINK))
         )
 
-    *Note*: Several actions cannot be Chained, and will raise an exception.
+    *Note*: Several Actions cannot be Chained, and will raise an exception.
     """
 
-    @beat("{} performs a complicated series of actions!")
+    @beat("{} performs a thrilling chain of Actions!")
     def perform_as(self, the_actor: Actor) -> None:
-        """Choreograph the actions and direct the actor to perform the chain."""
+        """Choreograph the Actions and direct the Actor to perform the chain."""
         browser = the_actor.ability_to(BrowseTheWeb).browser
         the_chain = ActionChains(browser)
 
         for action in self.actions:
             if "add_to_chain" not in dir(action):
                 raise UnableToAct(
-                    f"The {action.__class__.__name__} action cannot be chained."
+                    f"The {action.__class__.__name__} Action cannot be chained."
                 )
             action.add_to_chain(the_actor, the_chain)
         the_chain.perform()
