@@ -1,12 +1,13 @@
 """
-An action to clear text from an input.
+Clear text from an input.
 """
 
+from selenium.common.exceptions import WebDriverException
+
 from screenpy.actor import Actor
 from screenpy.exceptions import DeliveryError
 from screenpy.pacing import beat
 from screenpy.target import Target
-from selenium.common.exceptions import WebDriverException
 
 
 class Clear:
@@ -22,14 +23,14 @@ class Clear:
 
     @staticmethod
     def the_text_from_the(target: Target) -> "Clear":
-        """Specify which target from which to clear the text."""
+        """Specify the Target from which to clear the text."""
         return Clear(target)
 
     the_text_from = the_text_from_the
 
     @beat("{} clears text from the {target}.")
     def perform_as(self, the_actor: Actor) -> None:
-        """Direct the actor to clear the text from the targeted input field."""
+        """Direct the Actor to clear the text from the input field."""
         element = self.target.found_by(the_actor)
 
         try:
@@ -39,7 +40,7 @@ class Clear:
                 "Encountered an issue while attempting to clear "
                 f"{self.target}: {e.__class__.__name__}"
             )
-            raise DeliveryError(msg).with_traceback(e.__traceback__)
+            raise DeliveryError(msg) from e
 
     def __init__(self, target: Target) -> None:
         self.target = target
