@@ -1,5 +1,5 @@
 """
-An action to dismiss an alert.
+Dismiss a javascript alert.
 """
 
 from screenpy.abilities import BrowseTheWeb
@@ -20,7 +20,7 @@ class DismissAlert:
 
     @beat("{} dismisses the alert.")
     def perform_as(self, the_actor: Actor) -> None:
-        """Direct the actor to dismiss the alert."""
+        """Direct the Actor to dismiss the alert."""
         browser = the_actor.uses_ability_to(BrowseTheWeb).browser
         alert = browser.switch_to.alert
         aside(f'... the alert says "{alert.text}"')
