@@ -1,7 +1,9 @@
 """
-An action to send an API request.
+Send an API request.
 """
 
+from typing import Any
+
 from screenpy.abilities import MakeAPIRequests
 from screenpy.actor import Actor
 from screenpy.pacing import aside, beat
@@ -10,7 +12,7 @@ from screenpy.pacing import aside, beat
 class SendAPIRequest:
     """Send an API request.
 
-    You can use this action class directly if you wish, but the
+    You can use this Action class directly if you wish, but the
     Send{METHOD}Request classes are easier to read.
 
     Abilities Required:
@@ -27,7 +29,7 @@ class SendAPIRequest:
         )
     """
 
-    def with_(self, **kwargs) -> "SendAPIRequest":
+    def with_(self, **kwargs: Any) -> "SendAPIRequest":
         """Set additional kwargs to send through to the session's request.
 
         Args:
@@ -36,10 +38,17 @@ class SendAPIRequest:
         self.kwargs = kwargs
         return self
 
+    def which_should_be_kept_secret(self) -> "SendAPIRequest":
+        """Indicate the extra data should not be written to the log."""
+        self.secret = True
+        return self
+
+    secretly = which_should_be_kept_secret
+
     @beat("{} sends a {method} request to {url}")
     def perform_as(self, the_actor: Actor) -> None:
-        """Direct the actor to send an API request to the stored URL."""
-        if self.kwargs:
+        """Direct the Actor to send an API request to the stored URL."""
+        if self.kwargs and not self.secret:
             aside(f"... along with the following: {self.kwargs}")
 
         the_actor.uses_ability_to(MakeAPIRequests).to_send(
@@ -50,3 +59,4 @@ class SendAPIRequest:
         self.method = method.upper()
         self.url = url
         self.kwargs = {}
+        self.secret = False
