@@ -9,11 +9,15 @@ Given, When, and Then are Gherkin-style directives. The general idea is:
 All of these are identity functions, only used to provide a little extra
 context to your tests. An example test flow might be:
 
-    given(Perry).was_able_to(Start.on_the_homepage())
-    and_(Perry).was_able_to(LoginSuccessfully.using(USERNAME, PASSWORD))
+    given(Perry).was_able_to(
+        Start.on_the_homepage(),
+        LogIn.using(USERNAME, PASSWORD),
+    )
+
     when(Perry).attempts_to(Click.on_the(LOGOUT_BUTTON))
-    then(Perry).should_see_the(
-        (Text.of_the(BANNER_MESSAGE), ReadsExactly("Goodbye!"))
+
+    then(Perry).should(
+        See.the(Text.of_the(BANNER_MESSAGE), ReadsExactly("Goodbye!"))
     )
 
 [The Gherkin reference](https://docs.cucumber.io/gherkin/reference/) can
