@@ -1,5 +1,5 @@
 """
-A question to discover the title of an Actor's active browser window.
+Investigate the title of an Actor's active browser window.
 """
 
 from screenpy.abilities import BrowseTheWeb
@@ -15,11 +15,11 @@ class BrowserTitle:
 
     Examples::
 
-        the_actor.should_see_the((BrowserTitle(), ReadsExactly("Welcome!")))
+        the_actor.should(See.the(BrowserTitle(), ReadsExactly("Welcome!")))
     """
 
     @beat("{} reads the title of the page from their browser.")
     def answered_by(self, the_actor: Actor) -> str:
-        """Direct the actor to investigate the browser's title."""
+        """Direct the Actor to investigate the browser's title."""
         browser = the_actor.ability_to(BrowseTheWeb).browser
         return browser.title
