@@ -1,14 +1,15 @@
 """
-A question to retrieve an element from the page.
+Investigate an element on the browser page.
 """
 
 from typing import Optional
 
+from selenium.webdriver.remote.webelement import WebElement
+
 from screenpy.actor import Actor
-from screenpy.exceptions import BrowsingError
+from screenpy.exceptions import TargetingError
 from screenpy.pacing import beat
 from screenpy.target import Target
-from selenium.webdriver.remote.webelement import WebElement
 
 
 class Element:
@@ -19,15 +20,15 @@ class Element:
 
     Examples::
 
-        the_actor.should_see_the((Element(WELCOME_BANNER), IsVisible()))
+        the_actor.should(See.the(Element(WELCOME_BANNER), IsVisible()))
     """
 
-    @beat('{} views the "{target}" element.')
+    @beat("{} inspects the {target}.")
     def answered_by(self, the_actor: Actor) -> Optional[WebElement]:
-        """Direct the actor to find the element."""
+        """Direct the Actor to find the element."""
         try:
             return self.target.found_by(the_actor)
-        except BrowsingError:
+        except TargetingError:
             return None
 
     def __init__(self, target: Target) -> None:
