@@ -1,13 +1,14 @@
 """
-A question to find a list of many elements.
+Investigate one or more elements.
 """
 
 from typing import List as ListType
 
+from selenium.webdriver.remote.webdriver import WebElement
+
 from screenpy.actor import Actor
 from screenpy.pacing import beat
 from screenpy.target import Target
-from selenium.webdriver.remote.webdriver import WebElement
 
 
 class List:
@@ -18,7 +19,7 @@ class List:
 
     Examples::
 
-        the_actor.should_see_the((List.of(CONFETTI), IsEmpty()))
+        the_actor.should(See.the(List.of(CONFETTI), IsEmpty()))
     """
 
     @staticmethod
@@ -30,7 +31,7 @@ class List:
 
     @beat("{} lists off the {target}.")
     def answered_by(self, the_actor: Actor) -> ListType[WebElement]:
-        """Direct the actor to rattle off the specified elements."""
+        """Direct the Actor to rattle off the specified elements."""
         return self.target.all_found_by(the_actor)
 
     def __init__(self, target: Target) -> None:
