@@ -1,5 +1,5 @@
 """
-A question to investigate the status code of the last API response received.
+Investigate the status code of the last API response received.
 """
 
 from screenpy import Actor
@@ -16,14 +16,14 @@ class StatusCodeOfTheLastResponse:
 
     Examples::
 
-        the_actor.should_see_the(
-            (StatusCodeOfTheLastResponse(), IsEqualTo(200))
+        the_actor.should(
+            See.the(StatusCodeOfTheLastResponse(), IsEqualTo(200))
         )
     """
 
     @beat("{} examines the status code of the last response they received.")
     def answered_by(self, the_actor: Actor) -> float:
-        """Direct the actor to investigate the status code of the last response."""
+        """Direct the Actor to investigate the status code of the last response."""
         responses = the_actor.ability_to(MakeAPIRequests).responses
         if len(responses) < 1:
             raise UnableToAnswer(f"{the_actor} has not yet received any API responses.")
