@@ -1,5 +1,5 @@
 """
-A question to discover the text of an alert.
+Investigate the text of an alert.
 """
 
 from screenpy.abilities import BrowseTheWeb
@@ -15,13 +15,13 @@ class TextOfTheAlert:
 
     Examples::
 
-        the_actor.should_see_the(
-            (TextOfTheAlert(), ReadsExactly("Danger, Will Robinson!"))
+        the_actor.should(
+            See.the(TextOfTheAlert(), ReadsExactly("Danger, Will Robinson!"))
         )
     """
 
     @beat("{} reads the text from the alert.")
     def answered_by(self, the_actor: Actor) -> str:
-        """Direct the actor to read off the alert's text."""
+        """Direct the Actor to read off the alert's text."""
         browser = the_actor.uses_ability_to(BrowseTheWeb).browser
         return browser.switch_to.alert.text
