@@ -31,11 +31,11 @@ class IsVisibleElement(BaseMatcher[Optional[object]]):
     ) -> None:
         """Describe the failing case."""
         if item is None:
-            mismatch_description.append_text("was None")
+            mismatch_description.append_text("was not even present.")
             return
         mismatch_description.append_text("was not visible.")
 
 
-def is_visible_element():
+def is_visible_element() -> IsVisibleElement:
     """This matcher matches any element that is visible."""
     return IsVisibleElement()
